@@ -2,7 +2,7 @@
 DerivedBundle is an abstract Bundle supertype for bundles that need to be
 run by CodaLab and that have dependencies (i.e. make and run bundles).
 '''
-from typing import List, ClassVar
+from typing import List
 
 from codalab.bundles.named_bundle import NamedBundle
 from codalab.common import UsageError
@@ -11,7 +11,7 @@ from codalab.objects.metadata_spec import MetadataSpec
 
 
 class DerivedBundle(NamedBundle):
-    METADATA_SPECS = list(NamedBundle.METADATA_SPECS)  # type: List[ClassVar]
+    METADATA_SPECS = list(NamedBundle.METADATA_SPECS)  # type: List
     # Don't format specs
     # fmt: off
     METADATA_SPECS.append(
